#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml
version:              1.3.14
visibility:           public
id:                   xml-1.3.14-9Z9ZesgMbrVGnsSsWvOX4O
key:                  xml-1.3.14-9Z9ZesgMbrVGnsSsWvOX4O
license:              BSD-3-Clause
copyright:            (c) 2007-2008 Galois Inc.
maintainer:           diatchki@galois.com
author:               Galois Inc.
homepage:             http://code.galois.com
synopsis:             A simple XML library.
description:          A simple XML library.
category:             Text, XML
abi:                  da508c4fd43077ab44c2fae4ef955a65
exposed:              True
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types

import-dirs:          /usr/lib/ghc-8.10.5/site-local/xml-1.3.14
library-dirs:         /usr/lib/ghc-8.10.5/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/xml-1.3.14
hs-libraries:         HSxml-1.3.14-9Z9ZesgMbrVGnsSsWvOX4O
depends:              base-4.14.2.0 bytestring-0.10.12.0 text-1.2.4.1
haddock-interfaces:   /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html:         /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

